This project is written and maintained by Cláudio Givisiez and
various contributors:


Django Saml2 Auth
-----------------

- Cláudio Givisiez



Pysaml2
-------

- Roland Hedberg and it's contributors



Contributors
------------

- ``_